@@ -19,7 +19,8 @@ from AnyQt.QtWidgets import (
 from AnyQt.QtGui import QColor, QIcon, QDesktopServices, QKeySequence
 
 from AnyQt.QtCore import (
-    Qt, QEvent, QSize, QUrl, QTimer, QFile, QByteArray, QSettings, QT_VERSION
+    Qt, QEvent, QSize, QUrl, QTimer, QFile, QByteArray, QSettings, QT_VERSION,
+    QObject
 )
 
 try:
@@ -34,7 +35,7 @@ except ImportError:
     USE_WEB_ENGINE = False
 
 
-from AnyQt.QtCore import pyqtProperty as Property
+from AnyQt.QtCore import pyqtProperty as Property, pyqtSignal as Signal
 
 if QT_VERSION >= 0x50000:
     from AnyQt.QtCore import QStandardPaths
@@ -235,6 +236,11 @@ class CanvasMainWindow(QMainWindow):
         self.scheme_widget.pathChanged.connect(self.setWindowFilePath)
         self.scheme_widget.modificationChanged.connect(self.setWindowModified)
 
+        dropfilter = UrlDropEventFilter(self)
+        dropfilter.urlDropped.connect(self.open_scheme_file)
+        self.scheme_widget.setAcceptDrops(True)
+        self.scheme_widget.installEventFilter(dropfilter)
+
         # QMainWindow's Dock widget
         self.dock_widget = CollapsibleDockWidget(objectName="main-area-dock")
         self.dock_widget.setFeatures(QDockWidget.DockWidgetMovable | \
@@ -292,10 +298,9 @@ class CanvasMainWindow(QMainWindow):
 
         tool_actions = self.current_document().toolbarActions()
 
-        (self.canvas_zoom_action, self.canvas_align_to_grid_action,
+        (self.canvas_align_to_grid_action,
          self.canvas_text_action, self.canvas_arrow_action,) = tool_actions
 
-        self.canvas_zoom_action.setIcon(canvas_icons("Search.svg"))
         self.canvas_align_to_grid_action.setIcon(canvas_icons("Grid.svg"))
         self.canvas_text_action.setIcon(canvas_icons("Text Size.svg"))
         self.canvas_arrow_action.setIcon(canvas_icons("Arrow.svg"))
@@ -536,6 +541,21 @@ class CanvasMainWindow(QMainWindow):
                     shortcut=QKeySequence(Qt.ShiftModifier | Qt.Key_R)
                     )
 
+        self.zoom_in_action = \
+            QAction(self.tr("Zoom in"), self,
+                    triggered=self.zoom_in,
+                    shortcut=QKeySequence(Qt.ControlModifier | Qt.Key_Plus))
+
+        self.zoom_out_action = \
+            QAction(self.tr("Zoom out"), self,
+                    triggered=self.zoom_out,
+                    shortcut=QKeySequence(Qt.ControlModifier | Qt.Key_Minus))
+
+        self.zoom_reset_action = \
+            QAction(self.tr("Reset Zoom"), self,
+                    triggered=self.zoom_reset,
+                    shortcut=QKeySequence(Qt.ControlModifier | Qt.Key_0))
+
         if sys.platform == "darwin":
             # Actions for native Mac OSX look and feel.
             self.minimize_action = \
@@ -650,6 +670,12 @@ class CanvasMainWindow(QMainWindow):
         self.view_menu.addAction(self.show_report_action)
 
         self.view_menu.addSeparator()
+        self.view_menu.addAction(self.zoom_in_action)
+        self.view_menu.addAction(self.zoom_out_action)
+        self.view_menu.addAction(self.zoom_reset_action)
+
+        self.view_menu.addSeparator()
+
         self.view_menu.addAction(self.toogle_margins_action)
         menu_bar.addMenu(self.view_menu)
 
@@ -1595,7 +1621,13 @@ class CanvasMainWindow(QMainWindow):
             self.__update_from_settings()
 
     def open_addons(self):
-        from .addons import AddonManagerDialog
+        from .addons import AddonManagerDialog, have_install_permissions
+        if not have_install_permissions():
+            QMessageBox(QMessageBox.Warning,
+                        "Add-ons: insufficient permissions",
+                        "Insufficient permissions to install add-ons. Try starting Orange "
+                        "as a system administrator or install Orange in user folders.",
+                        parent=self).exec_()
         dlg = AddonManagerDialog(self, windowTitle=self.tr("Add-ons"))
         dlg.setAttribute(Qt.WA_DeleteOnClose)
         return dlg.exec_()
@@ -1894,6 +1926,15 @@ class CanvasMainWindow(QMainWindow):
 
             QMainWindow.changeEvent(self, event)
 
+    def zoom_in(self):
+        self.scheme_widget.view().change_zoom(1)
+
+    def zoom_out(self):
+        self.scheme_widget.view().change_zoom(-1)
+
+    def zoom_reset(self):
+        self.scheme_widget.view().reset_zoom()
+
     def sizeHint(self):
         """
         Reimplemented from QMainWindow.sizeHint
@@ -2005,3 +2046,30 @@ def index(sequence, *what, **kwargs):
         if predicate(what, item_key):
             return i
     raise ValueError("%r not in sequence" % what)
+
+
+class UrlDropEventFilter(QObject):
+    urlDropped = Signal(QUrl)
+
+    def eventFilter(self, obj, event):
+        etype = event.type()
+        if etype == QEvent.DragEnter or etype == QEvent.DragMove:
+            mime = event.mimeData()
+            if mime.hasUrls() and len(mime.urls()) == 1:
+                url = mime.urls()[0]
+                if url.isLocalFile():
+                    filename = url.toLocalFile()
+                    _, ext = os.path.splitext(filename)
+                    if ext == ".ows":
+                        event.acceptProposedAction()
+                        return True
+
+        elif etype == QEvent.Drop:
+            mime = event.mimeData()
+            urls = mime.urls()
+            if urls:
+                url = urls[0]
+                self.urlDropped.emit(url)
+                return True
+
+        return QObject.eventFilter(self, obj, event)
