@@ -19,7 +19,7 @@ import Orange.misc
 from Orange.widgets import gui, settings
 from Orange.widgets.settings import SettingProvider
 from Orange.widgets.utils.sql import check_sql_input
-from Orange.canvas import report
+from Orange.widgets import report
 from Orange.widgets.visualize.owscatterplotgraph import OWScatterPlotGraph, InteractiveViewBox
 from Orange.widgets.widget import Msg, OWWidget, Input, Output
 from Orange.widgets.utils.annotated_data import (
@@ -267,13 +267,7 @@ class OWMDS(OWWidget):
         self.update_graph(reset_view=False)
 
     def init_attr_values(self):
-        domain = self.data.domain if self.data and len(self.data) else None
-        for model in self.models:
-            model.set_domain(domain)
-        self.graph.attr_color = self.data.domain.class_var if domain else None
-        self.graph.attr_shape = None
-        self.graph.attr_size = None
-        self.graph.attr_label = None
+        self.graph.set_domain(self.data)
 
     def prepare_data(self):
         pass
@@ -290,7 +284,7 @@ class OWMDS(OWWidget):
     @Inputs.data
     @check_sql_input
     def set_data(self, data):
-        """Set the input data set.
+        """Set the input dataset.
 
         Parameters
         ----------
