@@ -35,7 +35,7 @@ from Orange.widgets.visualize.utils import VizRankDialog
 from Orange.widgets.visualize.utils.plotutils import AnchorItem
 from Orange.widgets.visualize.owscatterplotgraph import OWScatterPlotGraph, InteractiveViewBox
 from Orange.widgets.widget import Input, Output
-from Orange.canvas import report
+from Orange.widgets import report
 from Orange.preprocess.score import ReliefF, RReliefF
 
 
